@@ -159,7 +159,8 @@ describe 'keystone' do
     it 'should bootstrap $enable_bootstrap is true' do
       if param_hash['enable_bootstrap']
         is_expected.to contain_exec('keystone-manage bootstrap').with(
-          :command     => 'keystone-manage bootstrap --bootstrap-password service_password',
+          :command     => 'keystone-manage bootstrap',
+          :environment => 'OS_BOOTSTRAP_PASSWORD=service_password',
           :user        => param_hash['keystone_user'],
           :refreshonly => true
         )
@@ -832,7 +833,9 @@ describe 'keystone' do
       default_params.merge({:enable_proxy_headers_parsing => true })
     end
 
-    it { is_expected.to contain_keystone_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
+    it { is_expected.to contain_oslo__middleware('keystone_config').with(
+      :enable_proxy_headers_parsing => true,
+    )}
   end
 
   describe 'setting sql policy driver' do
